/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.json;

import com.openexchange.ajax.requesthandler.AJAXActionService;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.oauth.OAuthService;
import com.openexchange.oauth.association.OAuthAccountAssociationService;
import com.openexchange.secret.SecretService;
import com.openexchange.session.Session;

/**
 * {@link AbstractOAuthAJAXActionService}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public abstract class AbstractOAuthAJAXActionService implements AJAXActionService {

    /**
     * The {@link DefaultDeferringURLService} reference.
     */
    public static final java.util.concurrent.atomic.AtomicReference<DispatcherPrefixService> PREFIX = new java.util.concurrent.atomic.AtomicReference<DispatcherPrefixService>();

    private static volatile OAuthService oAuthService;
    private static volatile OAuthAccountAssociationService oAuthAccountAssociationService;
    private static volatile SecretService secretService;

    /**
     * Sets the OAuth service
     *
     * @param oAuthService The OAuth service
     */
    public static void setOAuthService(final OAuthService oAuthService) {
        AbstractOAuthAJAXActionService.oAuthService = oAuthService;
    }

    /**
     * Gets the OAuth service
     *
     * @return The OAuth service
     */
    public static OAuthService getOAuthService() {
        return oAuthService;
    }

    public static void setSecretService(final SecretService secretService) {
        AbstractOAuthAJAXActionService.secretService = secretService;
    }

    public static String secret(final Session session) {
        return secretService.getSecret(session);
    }

    /**
     * Sets the <code>OAuthAccountAssociationService</code> instance
     *
     * @param oAuthAccountAssociationService The instance
     */
    public static void setOAuthAccountAssociationService(final OAuthAccountAssociationService oAuthAccountAssociationService) {
        AbstractOAuthAJAXActionService.oAuthAccountAssociationService = oAuthAccountAssociationService;
    }

    /**
     * Gets the <code>OAuthAccountAssociationService</code> instance
     *
     * @return The instance or <code>null</code>
     */
    public static OAuthAccountAssociationService getOAuthAccountAssociationService() {
        return oAuthAccountAssociationService;
    }

    /**
     * Initializes a new {@link AbstractOAuthAJAXActionService}.
     */
    protected AbstractOAuthAJAXActionService() {
        super();
    }

}
